# Siren --- Interactive Redescription Mining

Siren is an interactive tool for visual and interactive redescription mining.


### Installation

#### Dependencies
`python-siren` requires several other Python utilities, including wxPython Phoenix (for the GUI), Numpy, Scipy, Scikit-learn, Matplotlib, and Cartopy.

* python-dateutil (>= 2.8.1)
* shapely (>= 1.7.0)
* numpy (>= 1.13.0)
* scipy (>= 0.19.0)
* scikit-learn (>= 0.19.0)
* wxPython (>= 4.0.0)
* matplotlib (>= 2.1.0)
* cartopy (>= 0.14)

#### PIP
with pip, installation should be as easy as running 
`pip install python-siren`

this should provide the following commands:

* `exec_siren` to launch the interface for interactively mining and visualizing redescriptions
* `server_siren` to launch the server for off-loading computations
* `exec_clired` to run the command-line redescription mining algorithms

### More information
See https://members.loria.fr/EGalbrun/siren/

### License
Siren is licensed under Apache License v2.0. See attached file "LICENSE".

(c) Esther Galbrun and Pauli Miettinen, 2012
